"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
var SameSite;
(function (SameSite) {
    SameSite["Lax"] = "lax";
    SameSite["Strict"] = "strict";
})(SameSite = exports.SameSite || (exports.SameSite = {}));
class Cookie {
    constructor(value) {
        this.value = value;
    }
    secureCookie(options) {
        options = utils_1.parseCookieOptions(options);
        let cookie_value;
        cookie_value = `${this.value}; Path=${options.path}`;
        if (options.secure) {
            cookie_value += "; Secure";
        }
        if (options.httponly) {
            cookie_value += "; HttpOnly";
        }
        if (options.samesite) {
            cookie_value += `; SameSite=${options.samesite}`;
        }
        if (options.expires) {
            if (typeof options.expires == "number") {
                cookie_value += `; Expires=${cookieExpiration(options.expires)}`;
            }
        }
        return cookie_value;
    }
}
exports.Cookie = Cookie;
function cookieExpiration(hours, dateObject = false) {
    const dateNow = new Date();
    let returnObject;
    dateNow.setHours(dateNow.getHours() + hours);
    let expire_time = dateNow.toUTCString();
    if (dateObject) {
        returnObject = dateNow;
    }
    else {
        returnObject = expire_time;
    }
    return returnObject;
}
function setCommonCookie(res, name, value, options) {
    options = utils_1.parseCookieOptions(options);
    const expressCookieOptions = {
        httpOnly: options.httpOnly,
        path: options.path,
        secure: options.secure,
        sameSite: options.sameSite
    };
    if (options.expires) {
        if (typeof options.expires == "number") {
            const expireDate = new Date();
            expireDate.setHours(expireDate.getHours() + options.expires);
            expressCookieOptions.expires = expireDate;
        }
    }
    res.cookie(name, value, expressCookieOptions);
}
exports.setCommonCookie = setCommonCookie;
