"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const cookie_1 = require("./cookie");
class SecureCookie {
    constructor(options) {
        this.options = options;
    }
    adonis(response, name, value) {
        cookie_1.setCommonCookie(response, name, value, this.options);
    }
    express(res, name, value) {
        cookie_1.setCommonCookie(res, name, value, this.options);
    }
    hapi(h, name, value) {
        const options = utils_1.parseCookieOptions(this.options);
        const hapiCookieOptions = {
            isSecure: options.secure,
            isHttpOnly: options.httpOnly,
            isSameSite: options.sameSite,
            path: options.path
        };
        if (options.expires) {
            if (typeof options.expires == "number") {
                const expireMilliseconds = options.expires * 60 * 60 * 1000;
                hapiCookieOptions.ttl = expireMilliseconds;
            }
        }
        h.state(name, value, hapiCookieOptions);
    }
    koa(ctx, name, value) {
        const options = utils_1.parseCookieOptions(this.options);
        const koaCookieOptions = {
            sameSite: options.sameSite,
            path: options.path,
            secure: options.secure,
            httpOnly: options.httpOnly
        };
        if (options.expires) {
            if (typeof options.expires == "number") {
                const expireDate = new Date();
                expireDate.setHours(expireDate.getHours() + options.expires);
                koaCookieOptions.expires = expireDate;
            }
            ctx.cookies.set(name, value, koaCookieOptions);
        }
    }
    nest(res, name, value) {
        cookie_1.setCommonCookie(res, name, value, this.options);
    }
    sails(res, name, value) {
        cookie_1.setCommonCookie(res, name, value, this.options);
    }
    total(res, name, value) {
        cookie_1.setCommonCookie(res, name, value, this.options);
    }
}
exports.SecureCookie = SecureCookie;
